import styled from "styled-components";
import React, { useState } from "react";
import { Meta, StoryObj } from "@storybook/react";
import { Input, InputProps2 } from "./index";

const meta = {
  title: "component/Input/DefaultInput",
  component: Input,
  parameters: {
    layout: "centered",
  },
  tags: ["autodocs"],
} as Meta<typeof Input>;

export default meta;

type Story = StoryObj<typeof meta>;

export const Default: Story = (args: InputProps2) => {
  const [value, setValue] = useState(args.value);

  const onChangeValue = (e: React.ChangeEvent<HTMLInputElement>) => {
    setValue(e.target.value);
  };

  const onClearValue = () => {
    setValue("");
  };

  return (
    <Container>
      <Input
        {...args}
        value={value}
        onChange={onChangeValue}
        onClear={onClearValue}
      />
    </Container>
  );
};

Default.args = {
  value: "",
  placeholder: "placeholder",
};

export const Disabled: Story = (args: InputProps2) => {
  return <Input {...args} />;
};

Disabled.args = {
  value: "disabled",
  disabled: true,
};

export const Error: Story = (args: InputProps2) => {
  const [value, setValue] = useState(args.value);

  const onChangeValue = (e: React.ChangeEvent<HTMLInputElement>) => {
    setValue(e.target.value);
  };

  const onClearValue = () => {
    setValue("");
  };

  return (
    <Input
      {...args}
      value={value}
      onChange={onChangeValue}
      onClear={onClearValue}
      onError={() => true}
    />
  );
};

Error.args = {
  value: "error",
  onError: () => true,
};

export const Date: Story = (args: InputProps2) => {
  const [value, setValue] = useState();

  const onChangeDate = (e) => {
    setValue(e.target.value);
  };

  return <Input {...args} value={value} onChange={onChangeDate} />;
};

Date.args = {
  type: "date",
};

const Container = styled.div`
  #common-input {
  }
`;
