import styled from "styled-components";
import { Input, InputProps2 } from "../Input";
import { ChevronDownIcon, ChevronUpIcon } from "@assets/Icon";

export type NumberInputProps = Omit<InputProps2, "type" | "onChange"> & {
  onChange?: (value: string) => void;
  enableButton?: boolean;
  onError?: () => boolean;
  unit?: string;
};

export const NumberInput = ({
  value = 0,
  onChange,
  enableButton,
  onError = () => false,
  unit,
  ...attributes
}: NumberInputProps) => {
  const { min, max } = attributes;

  const onClickButton = (type: -1 | 1) => {
    const sum = Number(value) + type;

    if (min && sum < Number(min)) {
      return;
    }

    if (max && sum > Number(max)) {
      return;
    }

    onChange && onChange(sum.toString());
  };

  return (
    <Container>
      <Input
        {...attributes}
        type="text"
        value={value}
        onChange={(e) => {
          // 숫자 이외의 문자 제거
          const value = e.target.value.replace(/[^\d]/g, "");
          onChange && onChange(value);
        }}
      />

      {enableButton && (
        <ButtonContainer>
          <button onClick={() => onClickButton(1)}>
            <ChevronUpIcon />
          </button>
          <button onClick={() => onClickButton(-1)}>
            <ChevronDownIcon />
          </button>
        </ButtonContainer>
      )}
    </Container>
  );
};

const Container = styled.div`
  display: flex;
`;

const ButtonContainer = styled.div`
  display: flex;
  flex-direction: column;
  height: 40px;

  & > button {
    width: 100%;
    height: 50%;
    display: flex;
    align-items: center;
    justify-content: center;

    & > svg {
      width: 16px;
      height: 16px;
    }
  }
`;
