import styled from "styled-components";
import { ReactNode, useEffect, useState } from "react";
import { Portal } from "@src/utils";
import { XIcon } from "@src/assets/Icon";

export type ModalProps = {
  children: ReactNode;
  isOpen: boolean;
  onClose: () => void;
  zIndex?: number;
};

export const Modal = ({
  children,
  isOpen,
  onClose,
  zIndex = 99,
}: ModalProps): ReactNode | null => {
  const [container, setContainer] = useState<Element | null>(null);

  useEffect(() => {
    const modalRoot = document.createElement("div");
    document.body.appendChild(modalRoot);

    setContainer(modalRoot);

    return () => {
      document.body.removeChild(modalRoot);
    };
  }, []);

  if (!isOpen) {
    return null;
  }

  return (
    <Portal container={container}>
      <Background id="common-modal__background">
        <Container id="common-modal__container" style={{ zIndex: zIndex }}>
          <button onClick={onClose}>
            <XIcon />
          </button>
          <div id="common-modal__children" className="children">
            {children}
          </div>
        </Container>
      </Background>
    </Portal>
  );
};

const Background = styled.div`
  width: 100vw;
  height: 100vh;
  position: fixed;
  top: 0;
  left: 0;
  background-color: rgba(0, 0, 0, 0.4);
`;

const Container = styled.div`
  max-width: 100vw;
  display: flex;
  flex-direction: column;
  gap: 8px;
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);

  & > button {
    width: 40px;
    height: 40px;
    display: flex;
    align-items: center;
    justify-content: center;
    align-self: flex-end;
    background-color: rgba(0, 0, 0, 0.16);
    border: 0;
    border-radius: 50%;
    cursor: pointer;

    & > svg {
      width: 24px;
      height: 24px;
      stroke: #fff;
    }
  }

  .children {
    background-color: #fff;
  }
`;
