// import "./Table.scss";
import React from "react";
import { useState } from "react";
import { TableColumn, TableProps, Table } from "./index";
import { Meta, StoryObj } from "@storybook/react";
import {
  options as tableData,
  OptionTypes as TableTypes,
} from "../../Dropdown/DropdownOptionData";
import { PaginationContainer } from "./Table.styled";
import PaginationButtons from "../components/PaginationButtons";
import PageSizeDropdown from "../components/PageSizeDropdown";
import Checkbox from "../../Checkbox/index";

const meta = {
  title: "component/Table/DefaultTable",
  component: Table,
  parameters: {
    layout: "centered",
    docs: { source: { type: "code" } }, // JSX.Element를 props로 넘길 때 storybook 제대로 작동 안하는거 막음
  },
  tags: ["autodocs"],
} satisfies Meta<typeof Table>;

export default meta;
type Story = StoryObj<typeof meta>;

export const Default: Story = (args: TableProps<TableTypes>) => {
  const [page, setPage] = useState<number>(1);
  const [totalPages, setTotalPages] = useState<number>(tableData.length);
  const [size, setSize] = useState<number>(10);
  const [isChecked, setIsChecked] = useState<TableTypes[]>([]);
  const [isLoading, setIsLoading] = useState<boolean>(false);

  // 전체 체크
  const handleOnChangeAllCheckbox = (
    e: React.ChangeEvent<HTMLInputElement>
  ) => {
    setIsChecked(tableData);

    if (!e.target.checked) {
      setIsChecked([]);
    }
  };

  // 개별 체크
  const handleOnChangeCheckbox = (column: TableTypes) => {
    setIsChecked([...isChecked, column]);

    if (isChecked.some((data) => data.phonePlanId === column.phonePlanId)) {
      setIsChecked(isChecked.filter((v) => v !== column));
    }
  };

  const columnData: TableColumn<TableTypes>[] = [
    {
      label: (
        <Checkbox
          checked={isChecked.length === tableData.length}
          onChange={(e) => !isLoading && handleOnChangeAllCheckbox(e)}
        />
      ),
      renderCell: ({ row }) => (
        <Checkbox
          checked={isChecked?.some(
            (data) => data.phonePlanId === row.phonePlanId
          )}
          onChange={() => !isLoading && handleOnChangeCheckbox(row)}
        />
      ),
    },
    {
      label: "이름",
      accessKey: "name",
      isVisible: false,
    },
    {
      label: "카테고리",
      accessKey: "category",
    },
    {
      label: "callExp",
      accessKey: "callExp",
    },
    {
      label: "mailExp",
      accessKey: "mailExp",
    },
    {
      label: "dataExp",
      accessKey: "dataExp",
    },
    {
      label: "가격",
      accessKey: "price",
    },
  ];

  return (
    <>
      <Table
        {...args}
        columns={columnData}
        tableData={tableData.slice(0, size)}
        // isLoading={true}
      />
      {!isLoading && (
        <PaginationContainer>
          <PaginationButtons page={page} totalPages={totalPages} />
          <PageSizeDropdown size={size} />
        </PaginationContainer>
      )}
    </>
  );
};

Default.args = {
  columns: [],
  tableData: [],
};

export const Loading: Story = (args: TableProps<TableTypes>) => {
  const columnData: TableColumn<TableTypes>[] = [
    {
      label: <Checkbox checked={false} onChange={() => {}} />,
      renderCell: () => <Checkbox checked={false} onChange={() => {}} />,
      className: "checkbox_div",
    },
    {
      label: "이름",
      accessKey: "name",
    },
    {
      label: "카테고리",
      accessKey: "category",
    },
    {
      label: "callExp",
      accessKey: "callExp",
    },
    {
      label: "mailExp",
      accessKey: "mailExp",
    },
    {
      label: "dataExp",
      accessKey: "dataExp",
    },
    {
      label: "가격",
      accessKey: "price",
    },
  ];

  return <Table {...args} columns={columnData} />;
};

Loading.args = {
  columns: [],
  tableData: tableData.slice(0, 10),
  isLoading: true,
};
//
