import { generateUniqueId } from "@src/utils/generateUniqueId";
import { SetStateAction } from "react";

export type ToastType = "ERROR" | "INFOMATION" | "SUCCESS" | "WARNING";

export type ToastItem = {
  id: string;
  title: string;
  description?: string;
  type: ToastType;
};

type SetToast = React.Dispatch<SetStateAction<ToastItem[]>>;

class Toaster {
  setToast: SetToast = () => {
    return;
  };

  constructor(setState: SetToast | null) {
    if (setState) this.setToast = setState;
  }

  addToast({ title, description, type }: Omit<ToastItem, "id">) {
    this.setToast((state: ToastItem[]) => [
      { id: generateUniqueId(), title, description, type },
      ...state,
    ]);
  }

  removeToast(selectedId: ToastItem["id"]) {
    this.setToast((state: ToastItem[]) =>
      state.filter(({ id }) => id !== selectedId)
    );
  }

  error(content: Pick<ToastItem, "title" | "description">) {
    this.addToast({ type: "ERROR", ...content });
  }

  infomation(content: Pick<ToastItem, "title" | "description">) {
    this.addToast({ type: "INFOMATION", ...content });
  }

  success(content: Pick<ToastItem, "title" | "description">) {
    this.addToast({ type: "SUCCESS", ...content });
  }

  warning(content: Pick<ToastItem, "title" | "description">) {
    this.addToast({ type: "WARNING", ...content });
  }
}
export default Toaster;
